@@ -419,14 +419,14 @@ class Dataset(HDXObject):
                         if resource_name == updated_resource['name']:
                             logger.warning('Resource exists. Updating %s' % resource_name)
                             hdx.data.filestore_helper.FilestoreHelper.dataset_merge_filestore_resource(resource, updated_resource,
-                                                                             filestore_resources, ignore_fields)
+                                                                             filestore_resources, ignore_fields, **kwargs)
                             break
                 updated_resource_names = set()
                 for updated_resource in updated_resources:
                     updated_resource_name = updated_resource['name']
                     updated_resource_names.add(updated_resource_name)
                     if not updated_resource_name in resource_names:
-                        hdx.data.filestore_helper.FilestoreHelper.check_filestore_resource(updated_resource, ignore_fields, filestore_resources)
+                        hdx.data.filestore_helper.FilestoreHelper.check_filestore_resource(updated_resource, ignore_fields, filestore_resources, **kwargs)
                         self.resources.append(updated_resource)
 
                 if remove_additional_resources:
@@ -449,9 +449,9 @@ class Dataset(HDXObject):
                         if resource_name != updated_resource_name:
                             logger.warning('Changing resource name to: %s' % updated_resource_name)
                         hdx.data.filestore_helper.FilestoreHelper.dataset_merge_filestore_resource(resource, updated_resource,
-                                                                         filestore_resources, ignore_fields)
+                                                                         filestore_resources, ignore_fields, **kwargs)
                     else:
-                        hdx.data.filestore_helper.FilestoreHelper.check_filestore_resource(updated_resource, ignore_fields, filestore_resources)
+                        hdx.data.filestore_helper.FilestoreHelper.check_filestore_resource(updated_resource, ignore_fields, filestore_resources, **kwargs)
                         self.resources.append(updated_resource)
 
                 if remove_additional_resources:
@@ -626,7 +626,7 @@ class Dataset(HDXObject):
         sort = kwargs.get('sort')
         if not sort:
             if total_rows > page_size:
-                kwargs['sort'] = 'metadata_modified asc'
+                kwargs['sort'] = 'metadata_created asc'
             else:
                 kwargs['sort'] = 'relevance asc, metadata_modified desc'
         offset = kwargs.get('offset')
@@ -669,7 +669,7 @@ class Dataset(HDXObject):
                         break
                 else:
                     logger.debug(result)
-            if kwargs['sort'] != 'metadata_modified asc' and all_datasets and len(counts) != 1:  # Make sure counts are all same for multiple calls to HDX
+            if kwargs['sort'] != 'metadata_created asc' and all_datasets and len(counts) != 1:  # Make sure counts are all same for multiple calls to HDX
                 all_datasets = None
                 attempts += 1
             else:
@@ -729,7 +729,7 @@ class Dataset(HDXObject):
             List[Dataset]: list of datasets resulting from query
         """
         if 'sort' not in kwargs:
-            kwargs['sort'] = 'metadata_modified asc'
+            kwargs['sort'] = 'metadata_created asc'
         return cls.search_in_hdx(query='*:*', configuration=configuration, page_size=page_size, **kwargs)
 
     @staticmethod
